/**
 * Title: SystemManager - A Java interface for general management of processes on any platform.
 * Description:
 * Copyright:    Copyright (c) 2008
 * Company:      Morpheus
 * @author Stefano Adriani
 * @version 1.0
 */


package adriani.tutorial.system ;

import java.io.* ;


/**
* Class used to test the creation and management of new processes on a generic platform.
*/
public interface SystemManager {


// *******************************			SETTING STATE			***********************************************


	/**
	* This method should be called after creation of the <CODE>SystemManager</CODE> instance.<BR>
	* Developers implementing this method should document the structore of the input arrat. For example:<P>
	*
	* <CODE>enviroment[0]</CODE>: the HOME variabile.
	* <CODE>enviroment[1]</CODE>: the PATH variabile.
	* <CODE>enviroment[2]</CODE>: the CLASSPATH variabile.
	*
	* @param enviroment an array specifying all the necessary enviroment's variables.
 	*/
	public void setState(String[] enviroment) ;


// *******************************			PROCESS CREATION		***********************************************


	/**
	* The standard <CODE>exec()</CODE> method.
	*
	* @param command the absolute path of the command.
	* @param param a char array specifying some parameters (if necessary).
	* @param verbose if <CODE>true</CODE> the process input is printed on the console screen (using decimal ASCII codes).
 	*/
	public String exec(String command, char[] param, boolean verbose) ;


	/**
	* The standard <CODE>fork()</CODE> method.
	*
	* @param object the java <CODE>object</CODE> represeting the parent process.
	* @param param a <CODE>char</CODE> array specifying some parameters (if necessary).
	* @param verbose if <CODE>true</CODE> the process input is printed on the console screen (using decimal ASCII codes).
 	*/
	public int fork(Object object, char[] param, boolean verbose) ;


	/**
	* A place-holder method allowing to write an alternative implementation of the <CODE>fork()</CODE> system call
	* (for training purposes).
	*
	* @param object the java <CODE>object</CODE> represeting the parent process.
	* @param param a <CODE>char</CODE> array specifying some parameters (if necessary).
	* @param verbose if <CODE>true</CODE> some information about the parent object is printed on the console screen (using decimal ASCII codes).
 	*/
	public int clone(Object object, char[] param, boolean verbose) ;


// *******************************			PROCESS MANAGEMENT		***********************************************


	/**
	* Waits for the specified process (usually a child process).
	*
	* @param process the target process.
 	*/
	public void waitForChild(Process process) ;


	/**
	* Kills the specified process (usually a child process).
	*
	* @param process the target process.
 	*/
	public void killChild(Process process) ;


} // End of interface