/**
 * Title: SystemTester - A general class for testing operative system.
 * Description:
 * Copyright:    Copyright (c) 2008
 * Company:      Morpheus
 * @author Stefano Adriani
 * @version 1.0
 */


package adriani.tutorial.system ;

import java.io.* ;


/**
* Class used to test and collect information by a generic operative system.<BR>
* This class provides also some methods which allow to print on the standard output some information about
* the <CODE>System</CODE> object, the <CODE>Runtime</CODE> object and the current <CODE>Process</CODE>.
*
*/
public class SystemTester {


	/** The class (depending by the operative system) taking care of processes management.						*/
	public SystemManager manager ;

	/** This attribute specifies if this class must write some debug information on the standard output.		*/
	public boolean verbose ;


// *******************************			THREAD MANAGEMENT		***********************************************


	/**
	* Stops the current thread.
	*
	* @param value the number of seconds that is necessary to pause this thread.
 	*/
	public void wait(char value) {

	  int seconds = 0 ;
	  seconds = Integer.parseInt(value + "") ;
	  System.out.println("Parsed delay: " + seconds) ;
	  wait(seconds) ;
	}


	/**
	* Stops the current thread.
	*
	* @param value the number of seconds that is necessary to pause this thread.
 	*/
	public void wait(int seconds) {

      try {
		Thread thread = Thread.currentThread() ;
		thread.sleep(seconds*1000) ;
	  } catch(Exception e) {
		System.out.println("Errore durante la sospensione del thread: " + e.getClass()) ;
	  }
	}


// *******************************		COMMAND LINE OUTPUT		***********************************************


	/**
	* Print the list of available external commands, as specified by the input <CODE>String[]</CODE> parameter.
	* The command list should be implemented by the class extending <CODE>SystemTester</CODE>.
	*
	* @param commands the command list.
 	*/
	public void printHelp(String[] commands) {

		System.out.println("\nPer lanciare il comando desiderato usare la sintassi\n") ;
		System.out.println("\tjava " + getClass().getName() + " n o m\n") ;
		System.out.println("con:\n") ;
		System.out.println("\tn numero del comando [0.." + commands.length + "]") ;
		System.out.println("\to opzione di cattura dell'input/output [0|1]") ;
		System.out.println("\tm modalita' di esecuzione [0|1|2]\n") ;
		System.out.println("Elenco dei comandi disponibili (opzione n):\n") ;
		for (int i = 0;  i < commands.length; i++) System.out.println("\t" + i + " " + commands[i]) ;
	}


	/**
	* Prints some information about the current <CODE>Process</CODE> object.
 	*/
	public void infoProcess() {

	  Class thisClass = getClass() ;

	  System.out.println("\nPROCESS") ;
	  printLine(80) ;
	  System.out.println("Current class:              " + thisClass.getName()) ;
	  System.out.println("Class loader:               " + thisClass.getClassLoader()) ;
	  printLine(80) ;
	}


	/**
	* Prints some information about the current <CODE>System</CODE> object.
 	*/
	public void infoSystem() {

	  System.out.println("\nSYSTEM") ;
	  printLine(50) ;
	  System.out.println("Current time:              " + System.currentTimeMillis()/3600 + " ore") ;
	  printLine(50) ;
	}


	/**
	* Prints some information about the current <CODE>Runtime</CODE> object.
 	*/
	public void infoRuntime() {

	  Runtime runtime = Runtime.getRuntime() ;

	  System.out.println("\nRUNTIME") ;
	  printLine(60) ;
	  System.out.println("Processori:                " + runtime.availableProcessors()) ;
	  System.out.println("Memoria VM libera:         " + runtime.freeMemory()/1024 + " KB") ;
	  System.out.println("Memoria massima:           " + runtime.maxMemory()/1024 + " KB") ;
	  System.out.println("Memoria totale:            " + runtime.totalMemory()/1024 + " KB") ;
	  printLine(60) ;
	}


// *******************************			UTILITIES		***********************************************


	/**
	* Prints a line on the command line screen (stout).
	*
	* @param line the number characters "*" to print on the command line.
 	*/
	public void printLine(int line) {

	  for (int i = 0; i < line; i++) System.out.print("*") ;
	  System.out.println() ;
	}


} // End of class