/**
 * Title: WinTester - Testing creation of new processes on Windows.
 * Description:
 * Copyright:    Copyright (c) 2008
 * Company:      Morpheus
 * @author Stefano Adriani
 * @version 1.0
 */


package adriani.tutorial.system ;

import java.io.* ;


/**
* Class used to test the creation of new processes on the Windows platform.<P>
*
* <B>Remark:</B> since this class is designed for the Windows platform, current implentation DOES NOT
* contain a good "pure Java" code. For example, here it's not used the expected <CODE>File.separator</CODE>
* reference.
*/
public class WinTester extends SystemTester {


	// CLASS FIELDS
	// Place holder


	/**
	* The main method launched when application starts.<BR>
	* For the specification of the available input parameters see the source file, or
	* run this application the <CODE>h</CODE> option.
	*/
	public static void main(String args[]) {

		WinManager manager = new WinManager() ;
		WinTester application = new WinTester(manager, false) ;

		application.testCommands(args) ;
	}


// *******************************			WINTESTER CLASS		***********************************************


	/**
	* Empty constructor.
	*/
	public WinTester() { }


	/**
	* Standard constructor.
	*
	* @param manager the system implementation of the <CODE>SystemManager</CODE> interface.
	* @param verbose is true, the child's input is printed on the command line.
	*/
	public WinTester(WinManager manager, boolean verbose) {

		this.manager = manager ;
		this.verbose = verbose ;
	}


	/**
	* This method can be launched specifying three input parameters:
	*
	* <UL>
	* <LI><CODE>args[0]</CODE> specify the type of command to be executed (run this class with the <CODE>h</CODE> option).</LI>
	* <LI><CODE>args[1]</CODE> specify the mood of execution (0=NO_OUTPUT, 1=OUTPUT).</LI>
	* <LI><CODE>args[2]</CODE> specify how to handle the child (0=NO_WAIT, 1=WAIT, 2=KILL).</LI>
	* </UL>
	*/
	public void testCommands(String args[]) {

		// 1. Setting enviroment
		char[] param 		= {'h','0','0'} ;
		String javaHome		= new String("C:\\j2sdk1.4.2_03\\bin\\java") ;
		String javaClass 	= new String("-cp C:\\Work\\Build adriani.tutorial.system.WinTester 0 9") ;
		String[] enviroment	= { javaHome } ;
		manager.setState(enviroment) ;

		// 2. Preparing commands
		String[] cmd = new String[9] ;
		cmd[0] = new String("NESSUNA OPERAZIONE (delay)") ;
		cmd[1] = new String("foo.bat") ;
		cmd[2] = new String("start foo.bat") ;
		cmd[3] = new String("C:\\WINDOWS\\system32\\cmd") ;
		cmd[4] = new String("C:\\WINDOWS\\system32\\cmd \"start\"") ;
		cmd[5] = new String("C:\\WINDOWS\\system32\\cmd /C \"start\"") ;
		cmd[6] = new String("C:\\WINDOWS\\system32\\cmd /C \"delay\"") ;
		cmd[7] = new String("C:\\WINDOWS\\system32\\cmd /C \"start delay\"") ;
		cmd[8] = new String(javaHome + " " + javaClass) ;

		// 3. Reading input parameters
		if ((args != null) && (args.length > 0)) {
			System.out.print("\nWinTester avviato con parametri: ") ;
			for (int i = 0; i < args.length; i++) {
			  param[i] = args[i].trim().charAt(0) ;
			  System.out.print(param[i] + " ") ;
			}
		} else System.out.print("\nWinTester avviato senza parametri") ;
		System.out.println() ;

		// 4. Launching the new process
		switch(param[0]) {

		  // Examples for manager.exec()
		  case '0': wait(param[1]) ; 							break ;
		  case '1': manager.exec(cmd[1], param, verbose) ; 		break ;
		  case '2': manager.exec(cmd[2], param, verbose) ; 		break ;
		  case '3': manager.exec(cmd[3], param, verbose) ; 		break ;
		  case '4': manager.exec(cmd[4], param, verbose) ; 		break ;
		  case '5': manager.exec(cmd[5], param, verbose) ; 		break ;
		  case '6': manager.exec(cmd[6], param, verbose) ; 		break ;
		  case '7': manager.exec(cmd[7], param, verbose) ; 		break ;
		  case '8': manager.exec(cmd[8], param, verbose) ;		break ;

		  // Example for manager.fork()
		  case 'c': manager.clone(this, param, verbose) ; 		break ;
		  case 'f': manager.fork(this, param, verbose) ; 		break ;

		  // Printing general information
		  //case 'm': manager.getInput(null, false) ; 			break ;
		  case 'h': printHelp(cmd) ; 							break ;
		  case 'p': infoProcess() ; 							break ;
		  case 'r': infoRuntime() ; 							break ;
		  case 's': infoSystem() ; 								break ;
		  default : printHelp(cmd) ; 							break ;
		}

		System.out.println("WinTester: exiting now ...\n") ;
	}


} // End of class